==> haskell-wreq-0.5.2.1-64-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wreq.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wreq
version: 0.5.2.1
id: wreq-0.5.2.1-BmLIFeFVUFQBW6tYrDqniO
key: wreq-0.5.2.1-BmLIFeFVUFQBW6tYrDqniO
license: BSD-3-Clause
copyright: 2014 Bryan O'\''Sullivan
maintainer: bos@serpentine.com
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: http://www.serpentine.com/wreq
synopsis: An easy-to-use HTTP client library.
description:
    .
    A web client library that is designed for ease of use.
    .
    Tutorial: <http://www.serpentine.com/wreq/tutorial.html>
    .
    Features include:
    .
    * Simple but powerful `lens`-based API
    .
    * A solid test suite, and built on reliable libraries like
    http-client and lens
    .
    * Session handling includes connection keep-alive and pooling, and
    cookie persistence
    .
    * Automatic response body decompression
    .
    * Powerful multipart form and file upload handling
    .
    * Support for JSON requests and responses, including navigation of
    schema-less responses
    .
    * Basic and OAuth2 bearer authentication
    .
    * Early TLS support via the tls package
category: Web
abi: cd85d8891e05d9114158db117250ddcc
exposed: True
exposed-modules:
    Network.Wreq Network.Wreq.Cache Network.Wreq.Cache.Store
    Network.Wreq.Lens Network.Wreq.Session Network.Wreq.Types
hidden-modules: Network.Wreq.Internal Network.Wreq.Internal.AWS
                Network.Wreq.Internal.Lens Network.Wreq.Internal.Link
                Network.Wreq.Internal.OAuth1 Network.Wreq.Internal.Types
                Network.Wreq.Lens.Machinery Network.Wreq.Lens.TH Paths_wreq
import-dirs: /usr/lib/ghc-8.4.3/site-local/wreq-0.5.2.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/wreq-0.5.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/wreq-0.5.2.1
hs-libraries: HSwreq-0.5.2.1-BmLIFeFVUFQBW6tYrDqniO
depends:
    psqueues-0.2.7.0-BPqM29kOUwk3wJsDqYO9jn
    aeson-1.4.1.0-CAtUrtPFyRJHgUU1AjW5xX
    attoparsec-0.13.2.2-4MFu4FwP8md1mPYCeCzsdE
    authenticate-oauth-1.6-Cn2WAlzOnug98Y7EUUJiSn base-4.11.1.0
    base16-bytestring-0.1.1.6-I0igvRcEwRNBMqqPC2yQBh
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    containers-0.5.11.0 cryptonite-0.25-FWytOeO7q1U1VcDN91QFfT
    exceptions-0.10.0-4E5CMyEcw7c5SGR3xFIeNi ghc-prim-0.5.2.0
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    http-client-0.5.13.1-4FGgNXaIPaRFFyHndQhLfa
    http-client-tls-0.3.5.3-EjRrcncVg5f6mnKyjdfLJe
    http-types-0.12.2-J7rsnBvQDs89qTHkldL6BH
    lens-4.17-A5yuSdXdLjmKpBlpOnn6t2
    lens-aeson-1.0.2-6wLXvYD8QzDDIFuxqTFrN2
    memory-0.14.16-FrHKJ6EcQ5I95PPEhrgDqk
    mime-types-0.1.0.8-9tF87HO5ShrGIShG8eldW4
    time-locale-compat-0.1.1.5-DDznVvFVEsmlk0WqJppPg
    template-haskell-2.13.0.0 text-1.2.3.0 time-1.8.0.2
    unordered-containers-0.2.9.0-KPgljVKoY3VBKTw1tFbcre
abi-depends: psqueues-0.2.7.0-BPqM29kOUwk3wJsDqYO9jn=a25f782677851508655c9200f7ebfc2c
             aeson-1.4.1.0-CAtUrtPFyRJHgUU1AjW5xX=25adaf2f506e44c8d5bd8da34f9279d5
             attoparsec-0.13.2.2-4MFu4FwP8md1mPYCeCzsdE=4221e97be581adbf81c2554dcbaa8ab5
             authenticate-oauth-1.6-Cn2WAlzOnug98Y7EUUJiSn=1c76055f21118e73df6412edad962d05
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base16-bytestring-0.1.1.6-I0igvRcEwRNBMqqPC2yQBh=bba358ad6d6aaa259e18cb7e07ede79c
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             cryptonite-0.25-FWytOeO7q1U1VcDN91QFfT=b157b67f4f829eb7de058ea2d8709fe0
             exceptions-0.10.0-4E5CMyEcw7c5SGR3xFIeNi=b417f0870e3d66d725c431d901a306c8
             ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             http-client-0.5.13.1-4FGgNXaIPaRFFyHndQhLfa=602a225eaa1cdcb9d9c8364c693edb16
             http-client-tls-0.3.5.3-EjRrcncVg5f6mnKyjdfLJe=d0a4fdcc5f61421bacdc690c38cb0b16
             http-types-0.12.2-J7rsnBvQDs89qTHkldL6BH=b88dec2e9e51949b7c6a738f8b360494
             lens-4.17-A5yuSdXdLjmKpBlpOnn6t2=4637bd44a39b4c072a280c87c676b7c9
             lens-aeson-1.0.2-6wLXvYD8QzDDIFuxqTFrN2=124862ced19db63da26f91a3907e7578
             memory-0.14.16-FrHKJ6EcQ5I95PPEhrgDqk=a0627d5d7afb3952e7ea8a317c372f9d
             mime-types-0.1.0.8-9tF87HO5ShrGIShG8eldW4=1f2d3d0537de744febdcb254f1bfc8b9
             time-locale-compat-0.1.1.5-DDznVvFVEsmlk0WqJppPg=8e7cbe9859e6b2fba2bf52bd3dee4d4a
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             unordered-containers-0.2.9.0-KPgljVKoY3VBKTw1tFbcre=264f905ec4c04eb05b5ff3d7321fae90
haddock-interfaces: /usr/share/doc/haskell-wreq/html/wreq.haddock
haddock-html: /usr/share/doc/haskell-wreq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wreq-0.5.2.1-72-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wreq.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wreq
version: 0.5.2.1
id: wreq-0.5.2.1-BnFGV3eyIbN7E9tNy8I5Gr
key: wreq-0.5.2.1-BnFGV3eyIbN7E9tNy8I5Gr
license: BSD-3-Clause
copyright: 2014 Bryan O'\''Sullivan
maintainer: bos@serpentine.com
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: http://www.serpentine.com/wreq
synopsis: An easy-to-use HTTP client library.
description:
    .
    A web client library that is designed for ease of use.
    .
    Tutorial: <http://www.serpentine.com/wreq/tutorial.html>
    .
    Features include:
    .
    * Simple but powerful `lens`-based API
    .
    * A solid test suite, and built on reliable libraries like
    http-client and lens
    .
    * Session handling includes connection keep-alive and pooling, and
    cookie persistence
    .
    * Automatic response body decompression
    .
    * Powerful multipart form and file upload handling
    .
    * Support for JSON requests and responses, including navigation of
    schema-less responses
    .
    * Basic and OAuth2 bearer authentication
    .
    * Early TLS support via the tls package
category: Web
abi: b158894082b04042941a399dc0ae24ca
exposed: True
exposed-modules:
    Network.Wreq Network.Wreq.Cache Network.Wreq.Cache.Store
    Network.Wreq.Lens Network.Wreq.Session Network.Wreq.Types
hidden-modules: Network.Wreq.Internal Network.Wreq.Internal.AWS
                Network.Wreq.Internal.Lens Network.Wreq.Internal.Link
                Network.Wreq.Internal.OAuth1 Network.Wreq.Internal.Types
                Network.Wreq.Lens.Machinery Network.Wreq.Lens.TH Paths_wreq
import-dirs: /usr/lib/ghc-8.6.1/site-local/wreq-0.5.2.1
library-dirs: /usr/lib/ghc-8.6.1/site-local/wreq-0.5.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/wreq-0.5.2.1
hs-libraries: HSwreq-0.5.2.1-BnFGV3eyIbN7E9tNy8I5Gr
depends:
    aeson-1.4.1.0-8dof3cdgEra8LhpTdWgCQb
    attoparsec-0.13.2.2-HPD0YgNwhBr5J2x8QxeYlI
    authenticate-oauth-1.6-I5uCUKJW21oFlw1fHTG8Sr base-4.12.0.0
    base16-bytestring-0.1.1.6-17atVnUhDnM13pAkKbwL6I
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu containers-0.6.0.1
    cryptonite-0.25-G72X72CTowDHXdsNScvcPv
    exceptions-0.10.0-6rXXyfyq3lH6yULL2y1jk1 ghc-prim-0.5.3
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    http-client-0.5.13.1-JGMG19H06puCrA9dS2QxMP
    http-client-tls-0.3.5.3-G4cyYsCQRJg4zk1NdcpOQj
    http-types-0.12.2-7y1WXD0L0v0C6qVqQcEAzr
    lens-4.17-8h7k4T9w40mJobS2zuaMS4
    lens-aeson-1.0.2-6KFFN0hrT6gIEgZQ8IYcb9
    memory-0.14.18-7DMShoecVUC5dB7z3aQ1xS
    mime-types-0.1.0.8-EyyVHsFtYS19TE9FosmRtL
    psqueues-0.2.7.0-F7SIn1Zw8RSGIXIqgqHmfA template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2
    time-locale-compat-0.1.1.5-4Kz46WDKPmGDmYVdO1w5q7
    unordered-containers-0.2.9.0-LB7iMl6A8usDj0EAzhnafU
haddock-interfaces: /usr/share/doc/haskell-wreq/html/wreq.haddock
haddock-html: /usr/share/doc/haskell-wreq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
